@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"11.4.7"
+#define MARIADB_CLIENT_VERSION_STR	"11.4.9"
 #define MARIADB_BASE_VERSION		"mariadb-11.4"
-#define MARIADB_VERSION_ID		110407
+#define MARIADB_VERSION_ID		110409
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                110407
-#define MYSQL_SERVER_VERSION            "11.4.7-MariaDB"
+#define MYSQL_VERSION_ID                110409
+#define MYSQL_SERVER_VERSION            "11.4.9-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.4.6"
-#define MARIADB_PACKAGE_VERSION_ID 30406
+#define MARIADB_PACKAGE_VERSION "3.4.8"
+#define MARIADB_PACKAGE_VERSION_ID 30408
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "sparc64"
+#define MARIADB_MACHINE_TYPE "riscv64"
 #define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
